import sys
import os
import pkg_resources
import platform


def this_extension():
    if getattr(sys, 'frozen', False):
        # The application is frozen
        return 'exe'
    else:
        # The application is not frozen
        return 'py'


def get_default_path(main_albacore_folder):
    default_path = os.path.join(main_albacore_folder, 'data')
    if not os.path.exists(default_path):
        if pkg_resources.resource_exists('albacore', 'data_versioned'):
            default_path = pkg_resources.resource_filename('albacore',
                                                           'data_versioned')
        elif platform.system() == 'Linux':
            default_path = '/opt/albacore'
        else:
            raise Exception('Unsupported platform '
                            '{}'.format(platform.system()))
    return default_path


def initialise_paths(save_path):
    read_path = os.path.join(save_path, 'workspace')
    create_dir_if_not_exist(read_path)
    return read_path


def create_dir_if_not_exist(target_dir):
    if not os.path.exists(target_dir):
        os.makedirs(target_dir)
