from datetime import datetime, timedelta
from dateutil.tz import tzlocal, tzutc

ISO3339_FMT = '%Y-%m-%dT%H:%M:%SZ'


def compute_start_timestamp(exp_start_time, offset_seconds):
    """ Convert experiment start time (can be either EPOCh or ISO 3339,
    depending on MinKNOW version), add start time of the read, and output
    as ISO 3339.
    :param exp_start_time timestamp of experiment start, either
    seconds since Jan 1, 1917 or UTC time string
    :param offset_seconds seconds to add
    :return ISO 3339 timestamp representing exp_start_time + offset_seconds
    """

    localtime = tzlocal()
    try:
        date_int = int(exp_start_time)
        new_exp_start = datetime.fromtimestamp(date_int, localtime)
        utc_exp_start = new_exp_start.astimezone(tzutc())
    except ValueError:
        # New minknow, check that the format is expected
        utc_exp_start = datetime.strptime(exp_start_time, ISO3339_FMT)
    utc_exp_start += timedelta(seconds=offset_seconds)
    return utc_exp_start.strftime(ISO3339_FMT)